/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.behavior;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.protocol.http.WebResponse;

/**
 * <p>
 * Behavior to disable browser caching. This also means that the page 
 * automatically expires the first time after it is rendered. 
 * </p>
 * 
 * <p>
 * Important: To make sure that form data cannot be submitted twice for
 * the same data using the back button, it is still necessary to explicitly call 
 * <code>getPage().getPageMap().remove(getPage());</code>
 * in the <code>onSubmit</code> callback of the form. 
 * </p>
 * 
 * @author Erik Brakkee
 * 
 */
public class DisableCachingBehavior extends ExpirePageImmediatelyBehavior {

    @Override
    public void setHeaders(WebPage aPage, WebResponse aResponse) {
        aResponse.setHeader("Pragma", "no-cache");
        aResponse.setHeader("Cache-Control",
            "no-cache, max-age=0, must-revalidate, no-store");
    }
}
